@@ -1,23 +1,19 @@
 import logging
 import re
-from enum import Enum
+import time
+from contextlib import closing
 from itertools import islice
 from logging import Logger
-from typing import TYPE_CHECKING, Dict, List, Union
+from typing import TYPE_CHECKING, Dict, List, Optional
 
 import confluent_kafka
 import pendulum
-from click import BadParameter
 from confluent_kafka.admin import ConfigResource
-from confluent_kafka.admin import TopicMetadata as ConfluentTopic
-from confluent_kafka.cimpl import NewTopic, TopicPartition
-from pykafka.topic import Topic as PyKafkaTopic
+from confluent_kafka.cimpl import KafkaException, NewTopic, TopicPartition
 
-from esque.clients.consumer import MessageConsumer
 from esque.config import ESQUE_GROUP_ID, Config
-from esque.errors import MessageEmptyException, raise_for_kafka_error
-from esque.helpers import ensure_kafka_future_done, invalidate_cache_after
-from esque.resources.topic import Partition, PartitionInfo, Topic, TopicDiff
+from esque.helpers import ensure_kafka_future_done
+from esque.resources.topic import Partition, Topic, TopicDiff
 
 logger: Logger = logging.getLogger(__name__)
 
@@ -25,33 +21,13 @@ if TYPE_CHECKING:
     from esque.cluster import Cluster
 
 
-class ClientTypes(Enum):
-    Confluent = "Confluent"
-    PyKafka = "PyKafka"
-
-
-ClientType = Union[ConfluentTopic, PyKafkaTopic]
-
-
 class TopicController:
-    def __init__(self, cluster: "Cluster", config: Config):
+    def __init__(self, cluster: "Cluster", config: Optional[Config] = None):
         self.cluster: "Cluster" = cluster
+        if config is None:
+            config = Config.get_instance()
         self.config = config
 
-    def _get_client_topic(self, topic_name: str, client_type: ClientTypes) -> ClientType:
-        confluent_topics = self.cluster.confluent_client.list_topics(topic=topic_name, timeout=10).topics
-        # Confluent returns a list of requested topics with an Error as result if the topic doesn't exist
-        topic_metadata: ConfluentTopic = confluent_topics[topic_name]
-        raise_for_kafka_error(topic_metadata.error)
-        if client_type == ClientTypes.Confluent:
-            return confluent_topics[topic_name]
-        elif client_type == ClientTypes.PyKafka:
-            # at least PyKafka does it's own caching, so we don't have to bother
-            pykafka_topics = self.cluster.pykafka_client.cluster.topics
-            return pykafka_topics[topic_name]
-        else:
-            raise BadParameter(f"TopicType needs to be part of {ClientTypes}", param=client_type)
-
     def list_topics(
         self,
         *,
@@ -60,7 +36,6 @@ class TopicController:
         hide_internal: bool = False,
         get_topic_objects: bool = True,
     ) -> List[Topic]:
-        self.cluster.confluent_client.poll(timeout=1)
         topic_results = self.cluster.confluent_client.list_topics().topics.values()
         topic_names = [t.topic for t in topic_results]
         if search_string:
@@ -76,7 +51,6 @@ class TopicController:
             topics = list(map(self.get_local_topic, topic_names))
         return topics
 
-    @invalidate_cache_after
     def create_topics(self, topics: List[Topic]):
         for topic in topics:
             partitions = (
@@ -92,8 +66,14 @@ class TopicController:
             )
             future_list = self.cluster.confluent_client.create_topics([new_topic], operation_timeout=60)
             ensure_kafka_future_done(next(islice(future_list.values(), 1)))
+            for _ in range(80):
+                topic_data = self.cluster.confluent_client.list_topics(topic=topic.name).topics[topic.name]
+                if topic_data.error is None:
+                    break
+                time.sleep(0.125)
+            else:
+                raise RuntimeError(f"Couldn't create topic {topic}")
 
-    @invalidate_cache_after
     def alter_configs(self, topics: List[Topic]):
         for topic in topics:
             altered_config = self._get_altered_config(topic)
@@ -112,7 +92,6 @@ class TopicController:
             altered_config[name] = value
         return altered_config
 
-    @invalidate_cache_after
     def delete_topic(self, topic: Topic):
         future = self.cluster.confluent_client.delete_topics([topic.name])[topic.name]
         ensure_kafka_future_done(future)
@@ -127,15 +106,15 @@ class TopicController:
     def get_offsets_closest_to_timestamp(
         self, group_id: str, topic_name: str, timestamp_limit: pendulum
     ) -> Dict[int, int]:
-        topic = self.get_cluster_topic(topic_name=topic_name)
         config = Config.get_instance().create_confluent_config()
         config.update({"group.id": group_id})
-        consumer = confluent_kafka.Consumer(config)
-        topic_partitions_with_timestamp = [
-            TopicPartition(topic.name, partition.partition_id, timestamp_limit.int_timestamp * 1000)
-            for partition in topic.partitions
-        ]
-        topic_partitions_with_new_offsets = consumer.offsets_for_times(topic_partitions_with_timestamp)
+        with closing(confluent_kafka.Consumer(config)) as consumer:
+            topic_data = consumer.list_topics(topic=topic_name).topics[topic_name]
+            topic_partitions_with_timestamp = [
+                TopicPartition(topic=topic_name, partition=partition_id, offset=timestamp_limit.int_timestamp * 1000)
+                for partition_id in topic_data.partitions.keys()
+            ]
+            topic_partitions_with_new_offsets = consumer.offsets_for_times(topic_partitions_with_timestamp)
         return {
             topic_partition.partition: topic_partition.offset for topic_partition in topic_partitions_with_new_offsets
         }
@@ -143,46 +122,47 @@ class TopicController:
     def update_from_cluster(self, topic: Topic, *, retrieve_last_timestamp: bool = False) -> Topic:
         """Takes a topic and, based on its name, updates all attributes from the cluster"""
 
-        confluent_topic: ConfluentTopic = self._get_client_topic(topic.name, ClientTypes.Confluent)
-        pykafka_topic: PyKafkaTopic = self._get_client_topic(topic.name, ClientTypes.PyKafka)
-        low_watermarks = pykafka_topic.earliest_available_offsets()
-        high_watermarks = pykafka_topic.latest_available_offsets()
-
-        topic.partition_data = self._get_partition_data(
-            confluent_topic, low_watermarks, high_watermarks, topic, retrieve_last_timestamp
-        )
+        topic.partition_data = self._get_partition_data(topic, retrieve_last_timestamp)
         topic.config = self.cluster.retrieve_config(ConfigResource.Type.TOPIC, topic.name)
 
         topic.is_only_local = False
 
         return topic
 
-    def _get_partition_data(
-        self,
-        confluent_topic: ConfluentTopic,
-        low_watermarks: PartitionInfo,
-        high_watermarks: PartitionInfo,
-        topic: Topic,
-        retrieve_last_timestamp: bool,
-    ) -> List[Partition]:
+    def _get_partition_data(self, topic: Topic, retrieve_last_timestamp: bool) -> List[Partition]:
 
-        consumer = MessageConsumer(ESQUE_GROUP_ID, topic.name, True, enable_auto_commit=False)
-        partitions = []
-
-        for partition_id, meta in confluent_topic.partitions.items():
-            low = int(low_watermarks[partition_id].offset[0])
-            high = int(high_watermarks[partition_id].offset[0])
-            latest_timestamp = None
-            if high > low and retrieve_last_timestamp:
+        config = Config.get_instance().create_confluent_config()
+        config.update({"group.id": ESQUE_GROUP_ID, "topic.metadata.refresh.interval.ms": "250"})
+        with closing(confluent_kafka.Consumer(config)) as consumer:
+            confluent_topic = consumer.list_topics(topic=topic.name).topics[topic.name]
+            partitions: List[Partition] = []
+            for partition_id, meta in confluent_topic.partitions.items():
                 try:
-                    latest_timestamp = float(consumer.consume(high - 1, partition_id).timestamp()[1]) / 1000
-                except MessageEmptyException:
-                    logger.warning(
-                        f"Due to timeout latest timestamp for topic `{topic.name}` and partition `{partition_id}` is missing."
+                    low, high = consumer.get_watermark_offsets(
+                        TopicPartition(topic=topic.name, partition=partition_id)
+                    )
+                except KafkaException:
+                    # retry after metadata should be refreshed (also consider small network delays)
+                    # unfortunately we cannot explicitly cause and wait for a metadata refresh
+                    time.sleep(1)
+                    low, high = consumer.get_watermark_offsets(
+                        TopicPartition(topic=topic.name, partition=partition_id)
                     )
-            partition = Partition(partition_id, low, high, meta.isrs, meta.leader, meta.replicas, latest_timestamp)
-            partitions.append(partition)
 
+                latest_timestamp = None
+                if high > low and retrieve_last_timestamp:
+                    assignment = [TopicPartition(topic=topic.name, partition=partition_id, offset=high - 1)]
+                    consumer.assign(assignment)
+                    msg = consumer.poll(timeout=10)
+                    if msg is None:
+                        logger.warning(
+                            f"Due to timeout latest timestamp for topic `{topic.name}` "
+                            f"and partition `{partition_id}` is missing."
+                        )
+                    else:
+                        latest_timestamp = float(msg.timestamp()[1]) / 1000
+                partition = Partition(partition_id, low, high, meta.isrs, meta.leader, meta.replicas, latest_timestamp)
+                partitions.append(partition)
         return partitions
 
     def diff_with_cluster(self, local_topic: Topic) -> TopicDiff:
